Tutorials
=========
Below are some examples describing how the PySwarms API works.
If you wish to check the actual Jupyter Notebooks, please go to this `link <https://github.com/ljvmiranda921/pyswarms/tree/master/examples>`_

.. toctree::

   basic_optimization
   custom_objective_function
   custom_optimization_loop
   visualization
